//
//  FlickrPhotoViewController.m
//  FlickrPhoto
//
//  Created by Toan Nguyen on 2012/08/23.
//  Copyright (c) 2012年 Tonkisoft. All rights reserved.
//

#import "FlickrPhotoViewController.h"
#import "FlickrFetcher.h"

@interface FlickrPhotoViewController () <UIScrollViewDelegate>
@property (weak, nonatomic) IBOutlet UIImageView *imageView;
@property (weak, nonatomic) IBOutlet UIScrollView *scrollView;
@end

@implementation FlickrPhotoViewController

#define NSUSERDEFAULTS @"FlickrPhotoRecentlyViewed"

@synthesize imageView = _imageView;
@synthesize scrollView = _scrollView;
@synthesize photo = _photo;

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.scrollView.delegate = self;
    self.title = [self.photo objectForKey:FLICKR_PHOTO_TITLE];
    
    // Load Flickr image using photoURL
    NSURL *photoURL = [FlickrFetcher urlForPhoto:self.photo format:FlickrPhotoFormatLarge];
    self.imageView.image = [UIImage imageWithData:[NSData dataWithContentsOfURL:photoURL]];
    
    // Set scrollView contentSize
    self.scrollView.contentSize = self.imageView.image.size;
    
    // Set frame of image
    self.imageView.frame = CGRectMake(0, 0, self.imageView.image.size.width, self.imageView.image.size.height);
}

- (void)viewWillAppear:(BOOL)animated{    
    // Update the zoom scale
    self.scrollView.zoomScale = [self calculateZoomScale];
    
    [self updateNSUserDefaults];
}

- (void)willAnimateRotationToInterfaceOrientation:(UIInterfaceOrientation)toInterfaceOrientation duration:(NSTimeInterval)duration
{
    //reset zoomScale back to 1 so that contentSize can be modified correctly
    self.scrollView.zoomScale = 1;
    
    // reset scrolling area equal to size of image
    self.scrollView.contentSize = self.imageView.image.size;
    
    //reset the image frame to the size of the image
    self.imageView.frame = CGRectMake(0, 0, self.imageView.image.size.width, self.imageView.image.size.height);
    
    // Update the zoom scale
    self.scrollView.zoomScale = [self calculateZoomScale];
}

- (void)viewDidUnload
{
    [self setImageView:nil];
    [self setScrollView:nil];
    [super viewDidUnload];
    // Release any retained subviews of the main view.
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return YES;
}

- (UIView *)viewForZoomingInScrollView:(UIScrollView *)scrollView
{
    return self.imageView;
}

- (float)calculateZoomScale
{
    // Width ratio compares the width of the viewing area with the width of the image
    float widthRatio = self.scrollView.bounds.size.width / self.imageView.image.size.width;
    
    // Height ratio compares the height of the viewing area with the height of the image
    float heightRatio = self.scrollView.bounds.size.height / self.imageView.image.size.height;
    
    return MAX(widthRatio, heightRatio);
}

- (void)updateNSUserDefaults
{
    // Save selected photo to NSUserDefaults. Photos saved as an array of NSDictionaries.
    NSUserDefaults *userDefaults = [NSUserDefaults standardUserDefaults];
    NSMutableArray *recentPhotos;
    
    if([userDefaults objectForKey:NSUSERDEFAULTS]){
        recentPhotos = [[userDefaults objectForKey:NSUSERDEFAULTS] mutableCopy];
    }
    else{
        recentPhotos = [NSMutableArray arrayWithCapacity:20];
    }
    
    // Search dictionary to see if photo already included. If it is, remove it and readd it to the top of the dictionary
    NSString *key = [self.photo objectForKey:FLICKR_PHOTO_ID];
    
    for(NSDictionary *dict in recentPhotos){
        if([[dict objectForKey:FLICKR_PHOTO_ID] isEqualToString:key]){
            [recentPhotos removeObject:dict];
            break;
        }
    }
    
    // If there are 20 photos already stored, remove the oldest one
    if(recentPhotos.count == 20){
        [recentPhotos removeLastObject];
    }
    
    // Add photo as first element of array
    [recentPhotos insertObject:self.photo atIndex:0];
    
    // Save data back to NSUserDefaults and synchronize
    [userDefaults setObject:recentPhotos forKey:NSUSERDEFAULTS];
    [userDefaults synchronize];
}
@end
