//
//  FlickrPhotoPlacesPhotosTableViewController.m
//  FlickrPhoto
//
//  Created by Toan Nguyen on 2012/08/23.
//  Copyright (c) 2012年 Tonkisoft. All rights reserved.
//

#import "FlickrPlacePhotoListTableViewController.h"
#import "FlickrPhotoViewController.h"
#import "FlickrFetcher.h"

@interface FlickrPlacePhotoListTableViewController ()
@property NSArray *photoArray;  // of Flickr photos in NSDictionary
@end

@implementation FlickrPlacePhotoListTableViewController

int const MAX_NUMBER_PHOTOS = 50;

@synthesize selectedPlace = _selectedPlace;
@synthesize photoArray = _photoArray;
@synthesize cityName = _cityName;

- (void) setSelectedPlace:(NSDictionary *)selectedPlace
{
    if(_selectedPlace != selectedPlace){
        _selectedPlace = selectedPlace;
        [self.tableView reloadData];
    }
}

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    NSArray *placePhotos = [FlickrFetcher photosInPlace:self.selectedPlace maxResults:MAX_NUMBER_PHOTOS];
    self.photoArray = placePhotos;
}

- (void)viewWillAppear:(BOOL)animated{
    self.navigationItem.title = self.cityName;
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return YES;
}

#pragma mark - Table view data source

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    // Return the number of rows in the section.
    return [self.photoArray count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Flickr Photos";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    
    // Configure the cell...
    
    // Fetch list of photos using FlickrFetcher
    NSDictionary *photo = [self.photoArray objectAtIndex:indexPath.row];
    NSString *photoTitle = [photo objectForKey:FLICKR_PHOTO_TITLE];
    NSString *photoDesc = [photo valueForKeyPath:FLICKR_PHOTO_DESCRIPTION];
    
    if(photoTitle && [photoTitle length] > 0){
        cell.textLabel.text = photoTitle;
        
        if(photoDesc){
            cell.detailTextLabel.text = photoDesc;
        }
    }
    else if(!photoTitle && (photoDesc && [photoDesc length] > 0)){
        cell.textLabel.text = photoDesc;
    }
    else{
        //TODO: Move @"Unknown" into constant var
        cell.textLabel.text = @"Unknown";
    }
    
    return cell;
}

#pragma mark - Table view delegate

- (void) prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender{
    if([segue.identifier isEqualToString:@"View Photo"]){
        FlickrPhotoViewController *newController = segue.destinationViewController;
        
        NSIndexPath *indexPath = [self.tableView indexPathForCell:sender];
        NSDictionary *selectedPhoto = [self.photoArray objectAtIndex:indexPath.row];
        
        [newController setPhoto:selectedPhoto];
    }
}

@end
