//
//  FlickrRecentlyViewedPhotosTableViewController.m
//  FlickrPhoto
//
//  Created by Toan Nguyen on 2012/08/24.
//  Copyright (c) 2012年 Tonkisoft. All rights reserved.
//

#import "FlickrRecentlyViewedPhotosTableViewController.h"
#import "FlickrPhotoViewController.h"
#import "FlickrFetcher.h"

@interface FlickrRecentlyViewedPhotosTableViewController ()

@end

@implementation FlickrRecentlyViewedPhotosTableViewController

#define NSUSERDEFAULTS @"FlickrPhotoRecentlyViewed"

@synthesize recentlyViewedPhotos = _recentlyViewed;

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
}

- (void)viewWillAppear:(BOOL)animated{
    [self loadDataFromNSUserDefaults];
    [self.tableView reloadData];
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

#pragma mark - Table view data source

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    // Return the number of rows in the section.
    return self.recentlyViewedPhotos.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Flickr Photos";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    
    // Configure the cell...
    NSDictionary *photo = [self.recentlyViewedPhotos objectAtIndex:indexPath.row];
    NSString *photoTitle = [photo objectForKey:FLICKR_PHOTO_TITLE];
    NSString *photoDesc = [photo valueForKeyPath:FLICKR_PHOTO_DESCRIPTION];
    
    if(photoTitle && [photoTitle length] > 0){
        cell.textLabel.text = photoTitle;
        
        if(photoDesc){
            cell.detailTextLabel.text = photoDesc;
        }
    }
    else if(!photoTitle && (photoDesc && [photoDesc length] > 0)){
        cell.textLabel.text = photoDesc;
    }
    else{
        //TODO: Move @"Unknown" into constant var
        cell.textLabel.text = @"Unknown";
    }
    
    return cell;
}

#pragma mark - Table view delegate

- (void) prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender{
    if([segue.identifier isEqualToString:@"View Photo"]){
        FlickrPhotoViewController *newController = segue.destinationViewController;
        
        NSIndexPath *indexPath = [self.tableView indexPathForCell:sender];
        NSDictionary *selectedPhoto = [self.recentlyViewedPhotos objectAtIndex:indexPath.row];
        
        [newController setPhoto:selectedPhoto];
    }
}

- (void)loadDataFromNSUserDefaults
{
    // Load recently viewed photos from NSUserDefaults
    NSUserDefaults *userDefaults = [NSUserDefaults standardUserDefaults];
    NSArray *recentPhotos = [[userDefaults objectForKey:NSUSERDEFAULTS] copy];
    self.recentlyViewedPhotos = recentPhotos;
}

@end
