//
//  FlickrPhotoTableViewController.m
//  FlickrPhoto
//
//  Created by Toan Nguyen on 2012/08/23.
//  Copyright (c) 2012年 Tonkisoft. All rights reserved.
//

#import "FlickrTopPlacesTableViewController.h"
#import "FlickrPlacePhotoListTableViewController.h"
#import "FlickrFetcher.h"

@interface FlickrTopPlacesTableViewController ()
+ (NSArray *)sortTopPlacesByAlphabeticalOrder:(NSArray *)topPlaces;
@end

@implementation FlickrTopPlacesTableViewController
@synthesize topPlaces = _topPlaces;

- (void) setTopPlaces:(NSArray *)topPlaces
{
    if(_topPlaces != topPlaces){
        _topPlaces = topPlaces;
        [self.tableView reloadData];
    }
}

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];

    NSArray *topPlaces = [FlickrFetcher topPlaces];
    self.topPlaces = [FlickrTopPlacesTableViewController sortTopPlacesByAlphabeticalOrder:topPlaces];
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return YES;
}

#pragma mark - Table view data source

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    // Return the number of rows in the section.
    return [self.topPlaces count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Flickr Top Places";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    
    // Configure the cell...
    
    // Fetch list of topPlaces using FlickrFetcher
    NSDictionary *place = [self.topPlaces objectAtIndex:indexPath.row];
    NSString *location = [place objectForKey:FLICKR_PLACE_NAME];
    
    // Divide location tag into city + region for title/subtitle
    NSArray *locationItems = [location componentsSeparatedByString:@", "];
    NSString *cityName = [locationItems objectAtIndex:0];
    NSString *regionInfo = @"";
    
    for(int i = 1; i < [locationItems count]; i++){
        // Only add comma if there is already an element in the string
        if([regionInfo length] > 0){
            regionInfo = [regionInfo stringByAppendingString:@", "];
        }
        regionInfo = [regionInfo stringByAppendingString:[locationItems objectAtIndex:i]];
    }

    cell.textLabel.text = cityName;
    cell.detailTextLabel.text = regionInfo;
    return cell;
}

#pragma mark - Table view delegate

- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender{
    if([segue.identifier isEqualToString:@"Places Photos"]){
        FlickrPlacePhotoListTableViewController *newController = segue.destinationViewController;
        
        NSIndexPath *indexPath = [self.tableView indexPathForCell:sender];
        NSDictionary *selectedPlace = [self.topPlaces objectAtIndex:indexPath.row];
        
        NSString *location = [selectedPlace objectForKey:FLICKR_PLACE_NAME];
        NSString *cityName = [[location componentsSeparatedByString:@", "] objectAtIndex:0];
        
        [newController setSelectedPlace:selectedPlace];
        [newController setCityName:cityName];
    }
}

// Helper method to sort topPlaces in alphabetical order
+ (NSArray *)sortTopPlacesByAlphabeticalOrder:(NSArray *)topPlaces{
    NSSortDescriptor *topPlaceDescriptor = [[NSSortDescriptor alloc] initWithKey:FLICKR_PLACE_NAME ascending:YES];
    NSArray *sortDescriptors = @[topPlaceDescriptor];
    NSArray *sortedTopPlaces = [topPlaces sortedArrayUsingDescriptors:sortDescriptors];
    return sortedTopPlaces;
}

@end
